"""This is module of "nester.py" """
def print_lol(this_list, level=0):
    """this function print contents of (nested)list
        to the stdout """
    for each_item in this_list:
        if isinstance(each_item, list):
            print_lol(each_item, level + 1)
        else:
            for i in range(level):
                print("\t", end='')
            print(each_item)



from distutils.core import setup

setup(
    name = "name_nester",
    version = "0.0.3",
    py_modules = ["nester"],
    author = "liulei",
    author_email = "liulei237136@gmail.com",
    url = "http://boocer.com",
    description = "A simple printer of nested lists"
)
